@@ -1,7 +1,8 @@
 //
 // This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 // Copyright (C) Michigan State University, 2009-2013. It is licensed under
-// the three-clause BSD license; see doc/LICENSE.txt. Contact: ctb@msu.edu
+// the three-clause BSD license; see doc/LICENSE.txt.
+// Contact: khmer-project@idyll.org
 //
 
 #include "perf_metrics.hh"
@@ -9,7 +10,7 @@
 namespace khmer
 {
 
-
+#ifdef WITH_INTERNAL_METRICS
 IPerformanceMetrics::
 IPerformanceMetrics( )
 { }
@@ -25,10 +26,10 @@ IPerformanceMetrics::
 _timespec_diff_in_nsecs( timespec const &start, timespec const &stop )
 {
     return
-	    ((stop.tv_sec * 1000000000U) + (uint64_t)stop.tv_nsec)
-	-   ((start.tv_sec * 1000000000U) + (uint64_t)start.tv_nsec);
+        ((stop.tv_sec * 1000000000U) + (uint64_t)stop.tv_nsec)
+        -   ((start.tv_sec * 1000000000U) + (uint64_t)start.tv_nsec);
 }
-
+#endif
 } // namespace khmer
 
 // vim: set ft=cpp sts=4 sw=4 tw=79:
