@@ -1,7 +1,8 @@
 //
 // This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 // Copyright (C) Michigan State University, 2009-2013. It is licensed under
-// the three-clause BSD license; see doc/LICENSE.txt. Contact: ctb@msu.edu
+// the three-clause BSD license; see doc/LICENSE.txt.
+// Contact: khmer-project@idyll.org
 //
 
 #include <fcntl.h>
@@ -15,22 +16,20 @@ namespace khmer
 {
 
 
+#ifdef WITH_INTERNAL_TRACING
 TraceLogger::
 TraceLogger( uint8_t const level, FILE * stream_handle )
-#ifdef WITH_INTERNAL_TRACING
-: _level( level ), _shared_stream( true ), _stream_handle( stream_handle )
+    : _level( level ), _shared_stream( true ), _stream_handle( stream_handle )
 {
     assert( NULL != stream_handle );
 }
-#else
-{ }
 #endif
 
 
 TraceLogger::
 TraceLogger( uint8_t const level, char const * const file_name_format, ... )
-: _level( level ), _shared_stream( false )
 #ifdef WITH_INTERNAL_TRACING
+    : _level( level ), _shared_stream( false )
 {
     char	tfile_name[ FILENAME_MAX + 1 ];
     va_list	varargs;
@@ -40,7 +39,9 @@ TraceLogger( uint8_t const level, char const * const file_name_format, ... )
     va_end( varargs );
 
     _stream_handle = fopen( tfile_name, "w" );
-    if (NULL == _stream_handle) throw InvalidStreamBuffer( );
+    if (NULL == _stream_handle) {
+        throw InvalidStreamBuffer( );
+    }
 
 }
 #else	// WITH_INTERNAL_TRACING
@@ -53,10 +54,9 @@ TraceLogger::
 #ifdef WITH_INTERNAL_TRACING
 {
 
-    if ((!_shared_stream) && (NULL != _stream_handle))
-    {
-	fclose( _stream_handle );
-	_stream_handle = NULL;
+    if ((!_shared_stream) && (NULL != _stream_handle)) {
+        fclose( _stream_handle );
+        _stream_handle = NULL;
     }
 
 }
