@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python2
 #
 # This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 # Copyright (C) Michigan State University, 2010-2014. It is licensed under
@@ -36,7 +36,7 @@ def get_parser():
     :program:`abundance_dist.py`.
     '''
     parser = build_counting_args(
-        descr="Caculate the abundance distribution of k-mers from a "
+        descr="Calculate the abundance distribution of k-mers from a "
         "single sequence file.", epilog=textwrap.dedent(epilog))
     add_threading_args(parser)
 
@@ -69,11 +69,12 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
     check_file_status(args.input_sequence_filename)
     check_space([args.input_sequence_filename])
     if args.savetable:
-        check_space_for_hashtable(args.ksize * args.min_tablesize)
+        check_space_for_hashtable(args.n_tables * args.min_tablesize)
 
     if (not args.squash_output and
             os.path.exists(args.output_histogram_filename)):
-        print >> sys.stderr, 'ERROR: %s exists; not squashing.' % args.histout
+        print >> sys.stderr, 'ERROR: %s exists; not squashing.' % \
+              args.output_histogram_filename
         sys.exit(1)
     else:
         hist_fp = open(args.output_histogram_filename, 'w')
@@ -95,14 +96,14 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
     khmer.get_config().set_reads_input_buffer_size(args.threads * 64 * 1024)
 
     # start loading
+    rparser = khmer.ReadParser(args.input_sequence_filename, args.threads)
     threads = []
     print 'consuming input, round 1 --', args.input_sequence_filename
     for _ in xrange(args.threads):
         thread = \
             threading.Thread(
                 target=counting_hash.consume_fasta_with_reads_parser,
-                args=(khmer.ReadParser(args.input_sequence_filename,
-                                       args.threads), )
+                args=(rparser, )
             )
         threads.append(thread)
         thread.start()
@@ -118,14 +119,14 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
         abundance_lists.append(abundances)
 
     print 'preparing hist from %s...' % args.input_sequence_filename
+    rparser = khmer.ReadParser(args.input_sequence_filename, args.threads)
     threads = []
     print 'consuming input, round 2 --', args.input_sequence_filename
     for _ in xrange(args.threads):
         thread = \
             threading.Thread(
                 target=__do_abundance_dist__,
-                args=(khmer.ReadParser(args.input_sequence_filename,
-                                       args.threads), )
+                args=(rparser, )
             )
         threads.append(thread)
         thread.start()
