@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python2
 #
 # This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 # Copyright (C) Michigan State University, 2009-2014. It is licensed under
@@ -28,6 +28,9 @@ from khmer.file import (check_space, check_space_for_hashtable,
                         check_valid_file_exists)
 DEFAULT_DESIRED_COVERAGE = 10
 
+MAX_FALSE_POSITIVE_RATE=0.8             # see Zhang et al.,
+                                        # http://arxiv.org/abs/1309.2975
+
 # Iterate a collection in arbitrary batches
 # from: http://stackoverflow.com/questions/4628290/pairs-from-single-list
 
@@ -139,13 +142,16 @@ def get_parser():
     keeping (or discarding) each sequencing fragment. This helps with retention
     of repeats, especially.
 
-    With :option:`-s`/:option:`--savetable`, the k-mer counting table will be
-    saved to the specified file after all sequences have been processed. With
-    :option:`-d`, the k-mer counting table will be saved every d files for
-    multifile runs; if :option:`-s` is set, the specified name will be used,
-    and if not, the name `backup.ct` will be used.
-    :option:`-l`/:option:`--loadtable` will load the specified k-mer counting
-    table before processsing the specified files.
+    With :option:`-s`/:option:`--savetable`, the k-mer counting table
+    will be saved to the specified file after all sequences have been
+    processed. With :option:`-d`, the k-mer counting table will be
+    saved every d files for multifile runs; if :option:`-s` is set,
+    the specified name will be used, and if not, the name `backup.ct`
+    will be used.  :option:`-l`/:option:`--loadtable` will load the
+    specified k-mer counting table before processing the specified
+    files.  Note that these tables are are in the same format as those
+    produced by :program:`load-into-counting.py` and consumed by
+    :program:`abundance-dist.py`.
 
     :option:`-f`/:option:`--fault-tolerant` will force the program to continue
     upon encountering a formatting error in a sequence file; the k-mer counting
@@ -170,7 +176,7 @@ def get_parser():
 
 """ "        normalize-by-median.py -k 17 -d 2 -s test.ct tests/test-data/test-abund-read-2.fa tests/test-data/test-fastq-reads")   # noqa
     parser = build_counting_args(
-        descr="Do digital normilization (remove mostly redundant sequences)",
+        descr="Do digital normalization (remove mostly redundant sequences)",
         epilog=textwrap.dedent(epilog))
     parser.add_argument('-C', '--cutoff', type=int,
                         default=DEFAULT_DESIRED_COVERAGE)
@@ -208,7 +214,7 @@ def main():  # pylint: disable=too-many-branches,too-many-statements
     check_valid_file_exists(args.input_filenames)
     check_space(args.input_filenames)
     if args.savetable:
-        check_space_for_hashtable(args.ksize * args.min_tablesize)
+        check_space_for_hashtable(args.n_tables * args.min_tablesize)
 
     # list to save error files along with throwing exceptions
     if args.force:
@@ -277,7 +283,6 @@ def main():  # pylint: disable=too-many-branches,too-many-statements
         print '...saving to', args.savetable
         htable.save(args.savetable)
 
-    # Change 0.2 only if you really grok it.  HINT: You don't.
     fp_rate = khmer.calc_expected_collisions(htable)
     print 'fp rate estimated to be {fpr:1.3f}'.format(fpr=fp_rate)
 
@@ -286,7 +291,7 @@ def main():  # pylint: disable=too-many-branches,too-many-statements
         print >> sys.stderr, "** IOErrors occurred in the following files:"
         print >> sys.stderr, "\t", " ".join(corrupt_files)
 
-    if fp_rate > 0.20:
+    if fp_rate > MAX_FALSE_POSITIVE_RATE:
         print >> sys.stderr, "**"
         print >> sys.stderr, ("** ERROR: the k-mer counting table is too small"
                               " for this data set.  Increase tablesize/# "
