@@ -1,10 +1,14 @@
 #
 # This file is part of khmer, http://github.com/ged-lab/khmer/, and is
 # Copyright (C) Michigan State University, 2009-2013. It is licensed under
-# the three-clause BSD license; see doc/LICENSE.txt. Contact: ctb@msu.edu
+# the three-clause BSD license; see doc/LICENSE.txt.
+# Contact: khmer-project@idyll.org
 #
+
+# pylint: disable=C0111,C0103
+
 import khmer
-import khmer_tst_utils as utils
+import tests.khmer_tst_utils as utils
 from nose.plugins.attrib import attr
 
 MAX_COUNT = 255
@@ -32,18 +36,17 @@ def test_collision():
 
 def test_complete_no_collision():
     kh = khmer.new_hashtable(4, 4 ** 4)
-    kt = khmer.new_ktable(4)
 
-    for i in range(0, kt.n_entries()):
-        s = kt.reverse_hash(i)
+    for i in range(0, kh.n_entries()):
+        s = khmer.reverse_hash(i, 4)
         kh.count(s)
 
     n_palindromes = 0
     n_rc_filled = 0
     n_fwd_filled = 0
 
-    for i in range(0, kt.n_entries()):
-        s = kt.reverse_hash(i)
+    for i in range(0, kh.n_entries()):
+        s = khmer.reverse_hash(i, 4)
         if kh.get(s):                   # string hashing is rc aware
             n_rc_filled += 1
         if kh.get(s) == 1:              # palindromes are singular
@@ -51,53 +54,51 @@ def test_complete_no_collision():
         if kh.get(i):                   # int hashing is not rc aware
             n_fwd_filled += 1
 
-    assert n_rc_filled == kt.n_entries(),  n_rc_filled
+    assert n_rc_filled == kh.n_entries(), n_rc_filled
     assert n_palindromes == 16, n_palindromes  # @CTB check this
-    assert n_fwd_filled == kt.n_entries() / 2 + n_palindromes / 2, \
+    assert n_fwd_filled == kh.n_entries() / 2 + n_palindromes / 2, \
         n_fwd_filled
 
 
 def test_complete_2_collision():
     kh = khmer.new_hashtable(4, 4 ** 4 / 2)
-    kt = khmer.new_ktable(4)
 
-    for i in range(0, kt.n_entries()):
-        s = kt.reverse_hash(i)
+    for i in range(0, kh.n_entries()):
+        s = khmer.reverse_hash(i, 4)
         kh.count(s)
 
     n_rc_filled = 0
-    n_fwd_filled = 0
+    #  n_fwd_filled = 0
 
     for i in range(0, 128):
-        s = kt.reverse_hash(i)
+        s = khmer.reverse_hash(i, 4)
         if kh.get(s):                   # string hashing is rc aware
             n_rc_filled += 1
-        if kh.get(i):                   # int hashing is not rc aware
-            n_fwd_filled += 1
+    #    if kh.get(i):                   # int hashing is not rc aware
+    #        n_fwd_filled += 1
 
-    assert n_rc_filled == 128,  n_rc_filled
+    assert n_rc_filled == 128, n_rc_filled
     # @CTB assert n_fwd_filled == 100 # kt.n_entries() / 2, n_fwd_filled
 
 
 def test_complete_4_collision():
     kh = khmer.new_hashtable(4, 4 ** 4 / 4)
-    kt = khmer.new_ktable(4)
 
-    for i in range(0, kt.n_entries()):
-        s = kt.reverse_hash(i)
+    for i in range(0, kh.n_entries()):
+        s = khmer.reverse_hash(i, 4)
         kh.count(s)
 
     n_rc_filled = 0
-    n_fwd_filled = 0
+    #  n_fwd_filled = 0
 
     for i in range(0, 64):
-        s = kt.reverse_hash(i)
+        s = khmer.reverse_hash(i, 4)
         if kh.get(s):                   # string hashing is rc aware
             n_rc_filled += 1
-        if kh.get(i):                   # int hashing is not rc aware
-            n_fwd_filled += 1
+    #   if kh.get(i):                   # int hashing is not rc aware
+    #       n_fwd_filled += 1
 
-    assert n_rc_filled == 64,  n_rc_filled
+    assert n_rc_filled == 64, n_rc_filled
     # @CTB assert n_fwd_filled == kt.n_entries() / 2, n_fwd_filled
 
 
@@ -106,7 +107,7 @@ def test_maxcount():
     kh = khmer.new_hashtable(4, 4 ** 4)
 
     last_count = None
-    for i in range(0, 10000):
+    for _ in range(0, 10000):
         kh.count('AAAA')
         c = kh.get('AAAA')
 
@@ -125,7 +126,7 @@ def test_maxcount_with_bigcount():
     kh.set_use_bigcount(True)
 
     last_count = None
-    for i in range(0, 10000):
+    for _ in range(0, 10000):
         kh.count('AAAA')
         c = kh.get('AAAA')
 
@@ -271,19 +272,19 @@ class Test_ConsumeString(object):
 
     def test_n_occupied(self):
         assert self.kh.n_occupied() == 0
-        n = self.kh.consume('AAAA')
+        self.kh.consume('AAAA')
         assert self.kh.n_occupied() == 1
-        n = self.kh.consume('AACT')
+        self.kh.consume('AACT')
         assert self.kh.n_occupied() == 2
 
     @attr('highmem')
     def test_abundance_by_pos(self):
         kh = self.kh
 
-        for i in range(0, 300):
+        for _ in range(0, 300):
             kh.count('ATCG')
 
-        for i in range(0, 10):
+        for _ in range(0, 10):
             kh.count('ATGG')
 
         short_filename = utils.get_test_data('test-short.fa')
@@ -301,10 +302,10 @@ class Test_ConsumeString(object):
         kh = self.kh
         kh.set_use_bigcount(True)       # count past MAX_COUNT
 
-        for i in range(0, 300):
+        for _ in range(0, 300):
             kh.count('ATCG')
 
-        for i in range(0, 10):
+        for _ in range(0, 10):
             kh.count('ATGG')
 
         short_filename = utils.get_test_data('test-short.fa')
@@ -319,15 +320,15 @@ class Test_ConsumeString(object):
 
     def test_n_occupied_args(self):
         assert self.kh.n_occupied() == 0
-        n = self.kh.consume('AAAA')
+        self.kh.consume('AAAA')
         assert self.kh.n_occupied(0, 1) == 1
         assert self.kh.n_occupied(1, 4 ** 4) == 0
 
-        hash = khmer.forward_hash('AACT', 4)
-        n = self.kh.consume('AACT')
-        assert self.kh.n_occupied(0, hash + 1) == 2
-        assert self.kh.n_occupied(hash + 1, 4 ** 4) == 0
-        assert self.kh.n_occupied(hash, hash + 1) == 1
+        hashvalue = khmer.forward_hash('AACT', 4)
+        self.kh.consume('AACT')
+        assert self.kh.n_occupied(0, hashvalue + 1) == 2
+        assert self.kh.n_occupied(hashvalue + 1, 4 ** 4) == 0
+        assert self.kh.n_occupied(hashvalue, hashvalue + 1) == 1
 
     def test_simple(self):
         n = self.kh.consume('AAAA')
